Enum pallet_xcm::pallet::Call [−][src]
pub enum Call<T: Config> {
send {
dest: Box<VersionedMultiLocation>,
message: Box<VersionedXcm<()>>,
},
teleport_assets {
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
},
reserve_transfer_assets {
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
},
execute {
message: Box<VersionedXcm<<T as SysConfig>::Call>>,
max_weight: Weight,
},
force_xcm_version {
location: Box<MultiLocation>,
xcm_version: XcmVersion,
},
force_default_xcm_version {
maybe_xcm_version: Option<XcmVersion>,
},
force_subscribe_version_notify {
location: Box<VersionedMultiLocation>,
},
force_unsubscribe_version_notify {
location: Box<VersionedMultiLocation>,
},
limited_reserve_transfer_assets {
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit,
},
limited_teleport_assets {
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Fields of send
dest: Box<VersionedMultiLocation>message: Box<VersionedXcm<()>>Teleport some assets from the local chain to some destination chain.
Fee payment on the destination side is made from the first asset listed in the assets vector and
fee-weight is calculated locally and thus remote weights are assumed to be equal to
local weights.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. The first item should be the currency used to to pay the fee on thedestside. May not be empty.dest_weight: Equal to the total weight ondestof the XCM messageTeleport { assets, effects: [ BuyExecution{..}, DepositAsset{..} ] }.
Fields of teleport_assets
dest: Box<VersionedMultiLocation>beneficiary: Box<VersionedMultiLocation>assets: Box<VersionedMultiAssets>fee_asset_item: u32Transfer some assets from the local chain to the sovereign account of a destination chain and forward a notification XCM.
Fee payment on the destination side is made from the first asset listed in the assets vector and
fee-weight is calculated locally and thus remote weights are assumed to be equal to
local weights.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. This should include the assets used to pay the fee on thedestside.fee_asset_item: The index intoassetsof the item which should be used to pay fees.
Fields of reserve_transfer_assets
dest: Box<VersionedMultiLocation>beneficiary: Box<VersionedMultiLocation>assets: Box<VersionedMultiAssets>fee_asset_item: u32Execute an XCM message from a local, signed, origin.
An event is deposited indicating whether msg could be executed completely or only
partially.
No more than max_weight will be used in its attempted execution. If this is less than the
maximum amount of weight that the message could take to be executed, then no execution
attempt will be made.
NOTE: A successful return to this does not imply that the msg was executed successfully
to completion; only that some of it was executed.
Fields of execute
message: Box<VersionedXcm<<T as SysConfig>::Call>>max_weight: WeightExtoll that a particular destination can be communicated with through a particular version of XCM.
origin: Must be Root.location: The destination that is being described.xcm_version: The latest version of XCM thatlocationsupports.
Fields of force_xcm_version
location: Box<MultiLocation>xcm_version: XcmVersionSet a safe XCM version (the version that XCM should be encoded with if the most recent version a destination can accept is unknown).
origin: Must be Root.maybe_xcm_version: The default XCM encoding version, orNoneto disable.
Fields of force_default_xcm_version
maybe_xcm_version: Option<XcmVersion>Ask a location to notify us regarding their XCM version and any changes to it.
origin: Must be Root.location: The location to which we should subscribe for XCM version notifications.
Fields of force_subscribe_version_notify
location: Box<VersionedMultiLocation>Require that a particular destination should no longer notify us regarding any XCM version changes.
origin: Must be Root.location: The location to which we are currently subscribed for XCM version notifications which we no longer desire.
Fields of force_unsubscribe_version_notify
location: Box<VersionedMultiLocation>Transfer some assets from the local chain to the sovereign account of a destination chain and forward a notification XCM.
Fee payment on the destination side is made from the first asset listed in the assets vector.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. This should include the assets used to pay the fee on thedestside.fee_asset_item: The index intoassetsof the item which should be used to pay fees.weight_limit: The remote-side weight limit, if any, for the XCM fee purchase.
Fields of limited_reserve_transfer_assets
dest: Box<VersionedMultiLocation>beneficiary: Box<VersionedMultiLocation>assets: Box<VersionedMultiAssets>fee_asset_item: u32weight_limit: WeightLimitTeleport some assets from the local chain to some destination chain.
Fee payment on the destination side is made from the first asset listed in the assets vector.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. The first item should be the currency used to to pay the fee on thedestside. May not be empty.dest_weight: Equal to the total weight ondestof the XCM messageTeleport { assets, effects: [ BuyExecution{..}, DepositAsset{..} ] }.weight_limit: The remote-side weight limit, if any, for the XCM fee purchase.
Fields of limited_teleport_assets
dest: Box<VersionedMultiLocation>beneficiary: Box<VersionedMultiLocation>assets: Box<VersionedMultiAssets>fee_asset_item: u32weight_limit: WeightLimitImplementations
pub fn new_call_variant_send(
dest: Box<VersionedMultiLocation>,
message: Box<VersionedXcm<()>>
) -> Self
pub fn new_call_variant_send(
dest: Box<VersionedMultiLocation>,
message: Box<VersionedXcm<()>>
) -> Self
Create a call with the variant send.
pub fn new_call_variant_teleport_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> Self
pub fn new_call_variant_teleport_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> Self
Create a call with the variant teleport_assets.
pub fn new_call_variant_reserve_transfer_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> Self
pub fn new_call_variant_reserve_transfer_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> Self
Create a call with the variant reserve_transfer_assets.
pub fn new_call_variant_execute(
message: Box<VersionedXcm<<T as SysConfig>::Call>>,
max_weight: Weight
) -> Self
pub fn new_call_variant_execute(
message: Box<VersionedXcm<<T as SysConfig>::Call>>,
max_weight: Weight
) -> Self
Create a call with the variant execute.
pub fn new_call_variant_force_xcm_version(
location: Box<MultiLocation>,
xcm_version: XcmVersion
) -> Self
pub fn new_call_variant_force_xcm_version(
location: Box<MultiLocation>,
xcm_version: XcmVersion
) -> Self
Create a call with the variant force_xcm_version.
pub fn new_call_variant_force_default_xcm_version(
maybe_xcm_version: Option<XcmVersion>
) -> Self
pub fn new_call_variant_force_default_xcm_version(
maybe_xcm_version: Option<XcmVersion>
) -> Self
Create a call with the variant force_default_xcm_version.
pub fn new_call_variant_force_subscribe_version_notify(
location: Box<VersionedMultiLocation>
) -> Self
pub fn new_call_variant_force_subscribe_version_notify(
location: Box<VersionedMultiLocation>
) -> Self
Create a call with the variant force_subscribe_version_notify.
pub fn new_call_variant_force_unsubscribe_version_notify(
location: Box<VersionedMultiLocation>
) -> Self
pub fn new_call_variant_force_unsubscribe_version_notify(
location: Box<VersionedMultiLocation>
) -> Self
Create a call with the variant force_unsubscribe_version_notify.
pub fn new_call_variant_limited_reserve_transfer_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> Self
pub fn new_call_variant_limited_reserve_transfer_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> Self
Create a call with the variant limited_reserve_transfer_assets.
pub fn new_call_variant_limited_teleport_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> Self
pub fn new_call_variant_limited_teleport_assets(
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> Self
Create a call with the variant limited_teleport_assets.