Enum pallet_xcm::pallet::Event [−][src]
pub enum Event<T: Config> {
Show 16 variants
Attempted(Outcome),
Sent(MultiLocation, MultiLocation, Xcm<()>),
UnexpectedResponse(MultiLocation, QueryId),
ResponseReady(QueryId, Response),
Notified(QueryId, u8, u8),
NotifyOverweight(QueryId, u8, u8, Weight, Weight),
NotifyDispatchError(QueryId, u8, u8),
NotifyDecodeFailed(QueryId, u8, u8),
InvalidResponder(MultiLocation, QueryId, Option<MultiLocation>),
InvalidResponderVersion(MultiLocation, QueryId),
ResponseTaken(QueryId),
AssetsTrapped(H256, MultiLocation, VersionedMultiAssets),
VersionChangeNotified(MultiLocation, XcmVersion),
SupportedVersionChanged(MultiLocation, XcmVersion),
NotifyTargetSendFail(MultiLocation, QueryId, XcmError),
NotifyTargetMigrationFail(VersionedMultiLocation, QueryId),
// some variants omitted
}Expand description
The event emitted by this pallet.
Variants
Attempted(Outcome)Execution of an XCM message was attempted.
[ outcome ]
Tuple Fields of Attempted
0: OutcomeSent(MultiLocation, MultiLocation, Xcm<()>)A XCM message was sent.
[ origin, destination, message ]
Tuple Fields of Sent
UnexpectedResponse(MultiLocation, QueryId)Query response received which does not match a registered query. This may be because a matching query was never registered, it may be because it is a duplicate response, or because the query timed out.
[ origin location, id ]
Tuple Fields of UnexpectedResponse
0: MultiLocation1: QueryIdQuery response has been received and is ready for taking with take_response. There is
no registered notification call.
[ id, response ]
Query response has been received and query is removed. The registered notification has been dispatched and executed successfully.
[ id, pallet index, call index ]
Query response has been received and query is removed. The registered notification could not be dispatched because the dispatch weight is greater than the maximum weight originally budgeted by this runtime for the query result.
[ id, pallet index, call index, actual weight, max budgeted weight ]
Query response has been received and query is removed. There was a general error with dispatching the notification call.
[ id, pallet index, call index ]
Query response has been received and query is removed. The dispatch was unable to be
decoded into a Call; this might be due to dispatch function having a signature which
is not (origin, QueryId, Response).
[ id, pallet index, call index ]
InvalidResponder(MultiLocation, QueryId, Option<MultiLocation>)Expected query response has been received but the origin location of the response does not match that expected. The query remains registered for a later, valid, response to be received and acted upon.
[ origin location, id, expected location ]
Tuple Fields of InvalidResponder
InvalidResponderVersion(MultiLocation, QueryId)Expected query response has been received but the expected origin location placed in storage by this runtime previously cannot be decoded. The query remains registered.
This is unexpected (since a location placed in storage in a previously executing runtime should be readable prior to query timeout) and dangerous since the possibly valid response will be dropped. Manual governance intervention is probably going to be needed.
[ origin location, id ]
Tuple Fields of InvalidResponderVersion
0: MultiLocation1: QueryIdResponseTaken(QueryId)Received query response has been read and removed.
[ id ]
Tuple Fields of ResponseTaken
0: QueryIdAssetsTrapped(H256, MultiLocation, VersionedMultiAssets)Some assets have been placed in an asset trap.
[ hash, origin, assets ]
Tuple Fields of AssetsTrapped
VersionChangeNotified(MultiLocation, XcmVersion)An XCM version change notification message has been attempted to be sent.
[ destination, result ]
Tuple Fields of VersionChangeNotified
0: MultiLocation1: XcmVersionSupportedVersionChanged(MultiLocation, XcmVersion)The supported version of a location has been changed. This might be through an automatic notification or a manual intervention.
[ location, XCM version ]
Tuple Fields of SupportedVersionChanged
0: MultiLocation1: XcmVersionNotifyTargetSendFail(MultiLocation, QueryId, XcmError)A given location which had a version change subscription was dropped owing to an error sending the notification to it.
[ location, query ID, error ]
Tuple Fields of NotifyTargetSendFail
NotifyTargetMigrationFail(VersionedMultiLocation, QueryId)A given location which had a version change subscription was dropped owing to an error migrating the location to our new XCM format.
[ location, query ID ]
Tuple Fields of NotifyTargetMigrationFail