Struct pallet_xcm::pallet::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn send(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
message: Box<VersionedXcm<()>>
) -> DispatchResult
pub fn teleport_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> DispatchResult
pub fn teleport_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> DispatchResult
Teleport some assets from the local chain to some destination chain.
Fee payment on the destination side is made from the first asset listed in the assets vector and
fee-weight is calculated locally and thus remote weights are assumed to be equal to
local weights.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. The first item should be the currency used to to pay the fee on thedestside. May not be empty.dest_weight: Equal to the total weight ondestof the XCM messageTeleport { assets, effects: [ BuyExecution{..}, DepositAsset{..} ] }.
pub fn reserve_transfer_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> DispatchResult
pub fn reserve_transfer_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32
) -> DispatchResult
Transfer some assets from the local chain to the sovereign account of a destination chain and forward a notification XCM.
Fee payment on the destination side is made from the first asset listed in the assets vector and
fee-weight is calculated locally and thus remote weights are assumed to be equal to
local weights.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. This should include the assets used to pay the fee on thedestside.fee_asset_item: The index intoassetsof the item which should be used to pay fees.
pub fn execute(
origin: OriginFor<T>,
message: Box<VersionedXcm<<T as SysConfig>::Call>>,
max_weight: Weight
) -> DispatchResult
pub fn execute(
origin: OriginFor<T>,
message: Box<VersionedXcm<<T as SysConfig>::Call>>,
max_weight: Weight
) -> DispatchResult
Execute an XCM message from a local, signed, origin.
An event is deposited indicating whether msg could be executed completely or only
partially.
No more than max_weight will be used in its attempted execution. If this is less than the
maximum amount of weight that the message could take to be executed, then no execution
attempt will be made.
NOTE: A successful return to this does not imply that the msg was executed successfully
to completion; only that some of it was executed.
pub fn force_xcm_version(
origin: OriginFor<T>,
location: Box<MultiLocation>,
xcm_version: XcmVersion
) -> DispatchResult
pub fn force_xcm_version(
origin: OriginFor<T>,
location: Box<MultiLocation>,
xcm_version: XcmVersion
) -> DispatchResult
Extoll that a particular destination can be communicated with through a particular version of XCM.
origin: Must be Root.location: The destination that is being described.xcm_version: The latest version of XCM thatlocationsupports.
pub fn force_default_xcm_version(
origin: OriginFor<T>,
maybe_xcm_version: Option<XcmVersion>
) -> DispatchResult
pub fn force_default_xcm_version(
origin: OriginFor<T>,
maybe_xcm_version: Option<XcmVersion>
) -> DispatchResult
Set a safe XCM version (the version that XCM should be encoded with if the most recent version a destination can accept is unknown).
origin: Must be Root.maybe_xcm_version: The default XCM encoding version, orNoneto disable.
pub fn force_subscribe_version_notify(
origin: OriginFor<T>,
location: Box<VersionedMultiLocation>
) -> DispatchResult
pub fn force_subscribe_version_notify(
origin: OriginFor<T>,
location: Box<VersionedMultiLocation>
) -> DispatchResult
Ask a location to notify us regarding their XCM version and any changes to it.
origin: Must be Root.location: The location to which we should subscribe for XCM version notifications.
pub fn force_unsubscribe_version_notify(
origin: OriginFor<T>,
location: Box<VersionedMultiLocation>
) -> DispatchResult
pub fn force_unsubscribe_version_notify(
origin: OriginFor<T>,
location: Box<VersionedMultiLocation>
) -> DispatchResult
Require that a particular destination should no longer notify us regarding any XCM version changes.
origin: Must be Root.location: The location to which we are currently subscribed for XCM version notifications which we no longer desire.
pub fn limited_reserve_transfer_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> DispatchResult
pub fn limited_reserve_transfer_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> DispatchResult
Transfer some assets from the local chain to the sovereign account of a destination chain and forward a notification XCM.
Fee payment on the destination side is made from the first asset listed in the assets vector.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. This should include the assets used to pay the fee on thedestside.fee_asset_item: The index intoassetsof the item which should be used to pay fees.weight_limit: The remote-side weight limit, if any, for the XCM fee purchase.
pub fn limited_teleport_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> DispatchResult
pub fn limited_teleport_assets(
origin: OriginFor<T>,
dest: Box<VersionedMultiLocation>,
beneficiary: Box<VersionedMultiLocation>,
assets: Box<VersionedMultiAssets>,
fee_asset_item: u32,
weight_limit: WeightLimit
) -> DispatchResult
Teleport some assets from the local chain to some destination chain.
Fee payment on the destination side is made from the first asset listed in the assets vector.
origin: Must be capable of withdrawing theassetsand executing XCM.dest: Destination context for the assets. Will typically beX2(Parent, Parachain(..))to send from parachain to parachain, orX1(Parachain(..))to send from relay to parachain.beneficiary: A beneficiary location for the assets in the context ofdest. Will generally be anAccountId32value.assets: The assets to be withdrawn. The first item should be the currency used to to pay the fee on thedestside. May not be empty.dest_weight: Equal to the total weight ondestof the XCM messageTeleport { assets, effects: [ BuyExecution{..}, DepositAsset{..} ] }.weight_limit: The remote-side weight limit, if any, for the XCM fee purchase.
Request that dest informs us of its version.
Request that dest ceases informing us of its version.
Relay an XCM message from a given interior location in this context to a given dest
location. A null dest is not handled.
pub fn report_outcome(
message: &mut Xcm<()>,
responder: impl Into<MultiLocation>,
timeout: T::BlockNumber
) -> Result<QueryId, XcmError>
pub fn report_outcome(
message: &mut Xcm<()>,
responder: impl Into<MultiLocation>,
timeout: T::BlockNumber
) -> Result<QueryId, XcmError>
Consume message and return another which is equivalent to it except that it reports
back the outcome.
message: The message whose outcome should be reported.responder: The origin from which a response should be expected.timeout: The block number after which it is permissible fornotifynot to be called even if a response is received.
report_outcome may return an error if the responder is not invertible.
To check the status of the query, use fn query() passing the resultant QueryId
value.
pub fn report_outcome_notify(
message: &mut Xcm<()>,
responder: impl Into<MultiLocation>,
notify: impl Into<<T as Config>::Call>,
timeout: T::BlockNumber
) -> Result<(), XcmError>
pub fn report_outcome_notify(
message: &mut Xcm<()>,
responder: impl Into<MultiLocation>,
notify: impl Into<<T as Config>::Call>,
timeout: T::BlockNumber
) -> Result<(), XcmError>
Consume message and return another which is equivalent to it except that it reports
back the outcome and dispatches notify on this chain.
message: The message whose outcome should be reported.responder: The origin from which a response should be expected.notify: A dispatchable function which will be called once the outcome ofmessageis known. It may be a dispatchable in any pallet of the local chain, but other than the usual origin, it must accept exactly two arguments:query_id: QueryIdandoutcome: Response, and in that order. It should expect that the origin isOrigin::Responseand will contain the responder’s location.timeout: The block number after which it is permissible fornotifynot to be called even if a response is received.
report_outcome_notify may return an error if the responder is not invertible.
NOTE: notify gets called as part of handling an incoming message, so it should be
lightweight. Its weight is estimated during this function and stored ready for
weighing ReportOutcome on the way back. If it turns out to be heavier once it returns
then reporting the outcome will fail. Futhermore if the estimate is too high, then it
may be put in the overweight queue and need to be manually executed.
Attempt to create a new query ID and register it as a query that is yet to respond.
pub fn new_notify_query(
responder: impl Into<MultiLocation>,
notify: impl Into<<T as Config>::Call>,
timeout: T::BlockNumber
) -> u64
pub fn new_notify_query(
responder: impl Into<MultiLocation>,
notify: impl Into<<T as Config>::Call>,
timeout: T::BlockNumber
) -> u64
Attempt to create a new query ID and register it as a query that is yet to respond, and which will call a dispatchable when a response happens.
Attempt to remove and return the response of query with ID query_id.
Returns None if the response is not (yet) available.
pub fn query<KArg>(k: KArg) -> Option<QueryStatus<T::BlockNumber>> where
KArg: EncodeLike<QueryId>,
pub fn query<KArg>(k: KArg) -> Option<QueryStatus<T::BlockNumber>> where
KArg: EncodeLike<QueryId>,
The ongoing queries.
The existing asset traps.
Key is the blake2 256 hash of (origin, versioned MultiAssets) pair. Value is the number of
times this pair has been trapped (usually just 1 if it exists at all).